@@ -1,5 +1,5 @@
-/*======================================================================
-----------------------------------------------------------------------*/
+//======================================================================
+//-----------------------------------------------------------------------
 /**
  * @file		iutest_pp_c.h
  * @brief		iris unit test vvZbT ` t@C
@@ -12,12 +12,17 @@
  * The new BSD License is applied to this software.
  * see LICENSE
 */
-/*----------------------------------------------------------------------
-======================================================================*/
+//-----------------------------------------------------------------------
+//======================================================================
 #ifndef INCG_IRIS_iutest_pp_C_H_E8F72184_9C72_4e74_B581_A1F51F291F3A_
 #define INCG_IRIS_iutest_pp_C_H_E8F72184_9C72_4e74_B581_A1F51F291F3A_
 
-/* define ============================================================*/
+//======================================================================
+// define
+
+#define IUTEST_PP_DISALLOW_COPY_AND_ASSIGN(TypeName)	\
+	TypeName( const TypeName& );						\
+	TypeName& operator = ( const TypeName& )
 
 #define IUTEST_PP_TOSTRING(z_)		IUTEST_PP_TOSTRING_(z_)
 #define IUTEST_PP_TOSTRING_(z_)		#z_
@@ -25,8 +30,6 @@
 #define IUTEST_PP_CAT(a_, b_)		IUTEST_PP_CAT_(a_, b_)
 #define IUTEST_PP_CAT_(a_, b_)		a_##b_
 
-#define IUTEST_PP_EMPTY
-
-#define IUTEST_UNUSED_VAR(x)		(void)(x)
+#define IUTEST_UNUSED_VAR(x)		(void)x
 
 #endif
