@@ -18,14 +18,13 @@
 */
 //-----------------------------------------------------------------------
 //======================================================================
-#ifndef INCG_IRIS_iutest_c_H_
-#define INCG_IRIS_iutest_c_H_
+#ifndef INCG_IRIS_iutest_H_
+#define INCG_IRIS_iutest_H_
 
 //======================================================================
 // include
 #include "iutest_ver_c.h"
 #include "iutest_core_c.h"
-#include "iutest_static_assertion_c.h"
 #include "listener/iutest_default_printer_c.h"
 #include "listener/iutest_default_xml_generator_c.h"
 
@@ -87,11 +86,6 @@
 */
 #define IUTEST_RUN_ALL_TESTS()						iuTestRun()
 
-/**
- * @ingroup TESTDEF
- * @brief	eXg𖾎Iɓo^
-*/
-#define IUTEST_REIGSTER_TEST(testcase_, testname_)	IUTEST_C_CALL_INITIALIZATION_SECTION(IIUT_C_TEST_INITIALIZATION_SECTION_NAME(testcase_, testname_))
 
 /**
  * @defgroup	IUTEST_ASSERT_	AT[V(ASSERT)
@@ -625,14 +619,12 @@ static void			iuTestInitialize(void);
 */
 static IUTEST_ATTRIBUTE_UNUSED_ void	iuInitIrisUnitTestA(int* argc, char** argv)
 {
-	iuTestEnv_LoadEnviromentVariable();
 	iuTestEnv_ParseCommandLineA(argc, argv);
 	iuTestInitialize();
 }
 #if IUTEST_C_HAS_WCHAR_T
 static IUTEST_ATTRIBUTE_UNUSED_ void	iuInitIrisUnitTestW(int* argc, wchar_t** argv)
 {
-	iuTestEnv_LoadEnviromentVariable();
 	iuTestEnv_ParseCommandLineW(argc, argv);
 	iuTestInitialize();
 }
@@ -654,16 +646,12 @@ static void			iuTestInitialize(void)
 		iuTestListener* listener = iuTestListener_MakeListener(&IIUT_C_UNITTEST().def_printer
 			, iuTestDefaultPrinter_OnTestProgramStart
 			, iuTestDefaultPrinter_OnTestIterationStart
-			, NULL
-			, NULL
 			, iuTestDefaultPrinter_OnTestCaseStart
 			, iuTestDefaultPrinter_OnTestStart
 			, iuTestDefaultPrinter_OnTestPartResult
 			, iuTestDefaultPrinter_OnTestRecordProperty
 			, iuTestDefaultPrinter_OnTestEnd
 			, iuTestDefaultPrinter_OnTestCaseEnd
-			, NULL
-			, NULL
 			, iuTestDefaultPrinter_OnTestIterationEnd
 			, iuTestDefaultPrinter_OnTestProgramEnd
 			);
@@ -677,16 +665,12 @@ static void			iuTestInitialize(void)
 		iuTestListener* listener = iuTestListener_MakeListener(&IIUT_C_UNITTEST().def_xml_generator
 			, iuTestDefaultXMLGenerator_OnTestProgramStart
 			, iuTestDefaultXMLGenerator_OnTestIterationStart
-			, NULL
-			, NULL
 			, iuTestDefaultXMLGenerator_OnTestCaseStart
 			, iuTestDefaultXMLGenerator_OnTestStart
 			, iuTestDefaultXMLGenerator_OnTestPartResult
 			, iuTestDefaultXMLGenerator_OnTestRecordProperty
 			, iuTestDefaultXMLGenerator_OnTestEnd
 			, iuTestDefaultXMLGenerator_OnTestCaseEnd
-			, NULL
-			, NULL
 			, iuTestDefaultXMLGenerator_OnTestIterationEnd
 			, iuTestDefaultXMLGenerator_OnTestProgramEnd
 			);
