@@ -25,15 +25,8 @@
 
 //======================================================================
 // define
-/**
- * @private
- * @{
-*/
 #define IIUT_C_TESTENV_NAME		g_iutest_c_testenv_instance
 #define IIUT_C_TESTENV()		IIUT_C_TESTENV_NAME
-/**
- * @}
-*/
 
 #define IUTEST_FLAG(name)	IIUT_C_TESTENV().option.name
 
@@ -41,54 +34,28 @@
 // enum
 typedef enum IUTESTENV_FLAG
 {
-	IUTESTENV_FILTERING_TESTS		= 0x0004,	//!< tB^O
-	IUTESTENV_CONSOLECOLOR_ON		= 0x0010,	//!< FoON
-	IUTESTENV_CONSOLECOLOR_OFF		= 0x0020,	//!< FoOFF
-	IUTESTENV_CONSOLECOLOR_ANSI		= 0x0040,	//!< GXP[vV[PXŏo
-	IUTESTENV_OUTPUT_XML_REPORT		= 0x0100,	//!< xml o
-	IUTESTENV_SHOWHELP_AND_SORRY	= 0x0400,	//!< wvo
-	IUTESTENV_SHOWHELP				= 0x0800,	//!< wvo
-	IUTESTENV_SHOWVER				= 0x1000,	//!< o[Wo
-	IUTESTENV_SHOWTESTSLIST			= 0x2000,	//!< eXgXgo
-	IUTESTENV_SHOWFEATURE			= 0x4000,	//!< @\o
+	IUTESTENV_FILTERING_TESTS		= 0x00000004,	//!< tB^O
+	IUTESTENV_CONSOLECOLOR_ON		= 0x00000100,	//!< FoON
+	IUTESTENV_CONSOLECOLOR_OFF		= 0x00000200,	//!< FoOFF
+	IUTESTENV_CONSOLECOLOR_ANSI		= 0x00000400,	//!< GXP[vV[PXŏo
+	IUTESTENV_OUTPUT_XML_REPORT		= 0x01000000,	//!< xml o
+	IUTESTENV_SHOWHELP_AND_SORRY	= 0x08000000,	//!< wvo
+	IUTESTENV_SHOWHELP				= 0x10000000,	//!< wvo
+	IUTESTENV_SHOWVER				= 0x20000000,	//!< o[Wo
+	IUTESTENV_SHOWTESTSLIST			= 0x40000000,	//!< eXgXgo
+	IUTESTENV_SHOWFEATURE			= 0x80000000,	//!< @\o
 
 	IUTESTENV_FLAG_DEFAULT			= 0
 } IUTESTENV_FLAG;
 
-//======================================================================
-// typedef
-typedef int (*iuVPrintf)(const char* fmt, va_list va);
-typedef void (*iuGlobalEnvironmentSetUp)(void);
-typedef void (*iuGlobalEnvironmentTearDown)(void);
-
 //======================================================================
 // struct
-/**
- * @brief	O[o SetUp \
-*/
-typedef struct iuTestGlobalEnvSetUp_t
-{
-	iuGlobalEnvironmentSetUp		func;	//!< SetUp ֐
-	struct iuTestGlobalEnvSetUp_t*	next;	//!< ̍\
-} iuTestGlobalEnvSetUp;
-
-/**
- * @brief	O[o TearDown \
-*/
-typedef struct iuTestGlobalEnvTearDown_t
-{
-	iuGlobalEnvironmentTearDown			func;	//!< TearDown ֐
-	struct iuTestGlobalEnvTearDown_t*	next;	//!< ̍\
-} iuTestGlobalEnvTearDown;
-
 /**
  * @brief	eXg\
 */
 typedef struct iuTestEnv_t
 {
 	iuTestListener*	listeners;		//!< Xi[Xg
-	iuTestGlobalEnvSetUp*		env_setup;		//!< O[o SetUp Xg
-	iuTestGlobalEnvTearDown*	env_teardown;	//!< O[o TearDown Xg
 	iuUInt32		flag;			//!< tO
 	iuUInt32		current_seed;	//!< V[ȟݒl
 	iuRandomContext	random_context;	//!< ReLXg
@@ -103,22 +70,14 @@ typedef struct iuTestEnv_t
 		iuBOOL			break_on_failure;			//!< eXgsɃu[N
 		iuBOOL			also_run_disabled_tests;	//!< DISABLED eXgs
 	} option;
-	iuVPrintf		pfnvpritf;			//!< vprintf ֐|C^
 	char			output_xml[260];	//!< oXMLt@CpX
 } iuTestEnv;
 
 //======================================================================
 // define
-/**
- * @private
- * @{
-*/
 #define iuTestEnvOption_ctor()	{ NULL, 1, 0, FALSE, TRUE, FALSE, FALSE }
-#define iuTestEnv_ctor()	{ NULL, NULL, NULL, IUTESTENV_FLAG_DEFAULT, 0, iuRandomContext_ctor()	\
-								, iuTestEnvOption_ctor(), NULL, {0} }
-/**
- * @}
-*/
+#define iuTestEnv_ctor()	{ NULL, IUTESTENV_FLAG_DEFAULT, 0, iuRandomContext_ctor()	\
+								, iuTestEnvOption_ctor(), {0} }
 
 //======================================================================
 // variable
@@ -126,41 +85,44 @@ extern iuTestEnv	IIUT_C_TESTENV_NAME;
 
 //======================================================================
 // function
-/**
- * @brief	eXgCX^X̎擾
-*/
-static IUTEST_ATTRIBUTE_UNUSED_ iuTestEnv* iuTestEnv_GetInstance(void)
-{
-	return &IIUT_C_TESTENV();
-}
-
-/**
- * @brief	vprintf ֐|C^ݒ
-*/
-static IUTEST_ATTRIBUTE_UNUSED_ void iuTestEnv_SetVPrintfFunction(iuVPrintf proc)
-{
-	iuTestEnv_GetInstance()->pfnvpritf = proc;
-}
 
 /**
  * @brief	TestListener ̒ǉ
 */
-static iuBOOL	iuTestEnv_AddTestListener(iuTestEnv* test_env, iuTestListener* test_listener)
+static int	iuTestEnv_AddTestListener(iuTestEnv* test_env, iuTestListener* test_listener)
 {
 	if( test_env == NULL ) return FALSE;
-	iuTestHelper_AddList(iuTestListener, test_env->listeners, test_listener);
+	if( test_listener == NULL ) return FALSE;
+	{
+		iuTestListener* top = test_env->listeners;
+		if( top == NULL )
+		{
+			test_env->listeners = test_listener;
+			return TRUE;
+		}
+		{
+			iuTestListener* prev = top;
+			iuTestListener* curr = top->next;
+			while( curr != NULL )
+			{
+				prev = curr;
+				curr = curr->next;
+			}
+			prev->next = test_listener;
+		}
+	}
 	return TRUE;
 }
 
 /**
  * @brief	TestListener ̍폜
 */
-static IUTEST_ATTRIBUTE_UNUSED_ iuBOOL	iuTestEnv_SubTestListener(iuTestEnv* test_env, iuTestListener* test_listener)
+static IUTEST_ATTRIBUTE_UNUSED_ int	iuTestEnv_SubTestListener(iuTestEnv* test_env, iuTestListener* test_listener)
 {
 	if( test_env == NULL ) return FALSE;
 	if( test_listener == NULL ) return FALSE;
 	{
-		iuTestListener *top = test_env->listeners;
+		iuTestListener* top = test_env->listeners;
 		if( top == NULL ) return FALSE;
 		if( top == test_listener )
 		{
@@ -169,8 +131,8 @@ static IUTEST_ATTRIBUTE_UNUSED_ iuBOOL	iuTestEnv_SubTestListener(iuTestEnv* test
 			return TRUE;
 		}
 		{
-			iuTestListener *prev = top;
-			iuTestListener *curr = top->next;
+			iuTestListener* prev = top;
+			iuTestListener* curr = top->next;
 			while( curr != NULL )
 			{
 				if( curr == test_listener )
@@ -187,73 +149,6 @@ static IUTEST_ATTRIBUTE_UNUSED_ iuBOOL	iuTestEnv_SubTestListener(iuTestEnv* test
 	return FALSE;
 }
 
-static iuTestGlobalEnvSetUp*	iuTestEnv_AllocGlobalEnvSetUp(void);
-static iuTestGlobalEnvTearDown*	iuTestEnv_AllocGlobalEnvTearDown(void);
-
-/**
- * @brief	GlobalEnvironmentSetUp ̒ǉ
-*/
-static IUTEST_ATTRIBUTE_UNUSED_ iuBOOL	iuTestEnv_AddGlobalEnvironmentSetUp(iuTestEnv* test_env, iuGlobalEnvironmentSetUp func)
-{
-	if( test_env == NULL ) return FALSE;
-	{
-		iuTestGlobalEnvSetUp* elem = iuTestEnv_AllocGlobalEnvSetUp();
-		if( elem == NULL ) return FALSE;
-		elem->func = func;
-		elem->next = NULL;
-		iuTestHelper_AddList(iuTestGlobalEnvSetUp, test_env->env_setup, elem);
-	}
-	return TRUE;
-}
-
-/**
- * @brief	GlobalEnvironmentTearDown ̒ǉ
-*/
-static IUTEST_ATTRIBUTE_UNUSED_ iuBOOL	iuTestEnv_AddGlobalEnvironmentTearDown(iuTestEnv* test_env, iuGlobalEnvironmentTearDown func)
-{
-	if( test_env == NULL ) return FALSE;
-	{
-		iuTestGlobalEnvTearDown* elem = iuTestEnv_AllocGlobalEnvTearDown();
-		if( elem == NULL ) return FALSE;
-		elem->func = func;
-		elem->next = NULL;
-		iuTestHelper_AddList(iuTestGlobalEnvTearDown, test_env->env_teardown, elem);
-	}
-	return TRUE;
-}
-
-/**
- * @brief	GlobalEnvironmentSetUp ̎s
-*/
-static void	iuTestEnv_GlobalEnvironmentSetUp(void)
-{
-	iuTestGlobalEnvSetUp* curr = IIUT_C_TESTENV().env_setup;
-	while( curr != NULL )
-	{
-		if( curr->func != NULL )
-		{
-			(*curr->func)();
-		}
-		curr = curr->next;
-	}
-}
-
-/**
- * @brief	GlobalEnvironmentTearDown ̎s
-*/
-static void	iuTestEnv_GlobalEnvironmentTearDown(void)
-{
-	iuTestGlobalEnvTearDown* curr = IIUT_C_TESTENV().env_teardown;
-	while( curr != NULL )
-	{
-		if( curr->func != NULL )
-		{
-			(*curr->func)();
-		}
-		curr = curr->next;
-	}
-}
-
 /**
  * @brief	OnTestProgramStart
 */
@@ -286,38 +181,6 @@ static void	iuTestEnv_ListenerEvent_OnTestIterationStart(struct iuUnitTest_t* un
 	}
 }
 
-/**
- * @brief	OnEnvironmentsSetUpStart
-*/
-static void	iuTestEnv_ListenerEvent_OnEnvironmentsSetUpStart(struct iuUnitTest_t* unit_test)
-{
-	iuTestListener* curr = IIUT_C_TESTENV().listeners;
-	while( curr != NULL )
-	{
-		if( curr->OnEnvironmentsSetUpStart != NULL )
-		{
-			(*curr->OnEnvironmentsSetUpStart)(unit_test);
-		}
-		curr = curr->next;
-	}
-}
-
-/**
- * @brief	OnEnvironmentsSetUpEnd
-*/
-static void	iuTestEnv_ListenerEvent_OnEnvironmentsSetUpEnd(struct iuUnitTest_t* unit_test)
-{
-	iuTestListener* curr = IIUT_C_TESTENV().listeners;
-	while( curr != NULL )
-	{
-		if( curr->OnEnvironmentsSetUpEnd != NULL )
-		{
-			(*curr->OnEnvironmentsSetUpEnd)(unit_test);
-		}
-		curr = curr->next;
-	}
-}
-
 /**
  * @brief	OnTestCaseStart
 */
@@ -414,38 +277,6 @@ static void	iuTestEnv_ListenerEvent_OnTestCaseEnd(struct iuTestCase_t* test_case
 	}
 }
 
-/**
- * @brief	OnEnvironmentsTearDownStart
-*/
-static void	iuTestEnv_ListenerEvent_OnEnvironmentsTearDownStart(struct iuUnitTest_t* unit_test)
-{
-	iuTestListener* curr = IIUT_C_TESTENV().listeners;
-	while( curr != NULL )
-	{
-		if( curr->OnEnvironmentsTearDownStart != NULL )
-		{
-			(*curr->OnEnvironmentsTearDownStart)(unit_test);
-		}
-		curr = curr->next;
-	}
-}
-
-/**
- * @brief	OnEnvironmentsTearDownEnd
-*/
-static void	iuTestEnv_ListenerEvent_OnEnvironmentsTearDownEnd(struct iuUnitTest_t* unit_test)
-{
-	iuTestListener* curr = IIUT_C_TESTENV().listeners;
-	while( curr != NULL )
-	{
-		if( curr->OnEnvironmentsTearDownEnd != NULL )
-		{
-			(*curr->OnEnvironmentsTearDownEnd)(unit_test);
-		}
-		curr = curr->next;
-	}
-}
-
 /**
  * @brief	OnTestIterationEnd
 */
@@ -483,7 +314,7 @@ static void	iuTestEnv_ListenerEvent_OnTestProgramEnd(struct iuUnitTest_t* unit_t
 */
 static void iuTestEnv_SetUp(iuTestEnv* test_env)
 {
-	iuUInt32 seed = test_env->option.random_seed;
+	unsigned int seed = test_env->option.random_seed;
 	if( seed == 0 )
 	{
 		seed = iuTest_GetIndefiniteValue();
@@ -616,7 +447,7 @@ static iuBOOL	iuTestEnv_ParseCommandLineElemA(const char* arg)
 				}
 				else if( iuString_IsStringEqual(arg, "also_run_disabled_tests") )
 				{
-					IUTEST_FLAG(also_run_disabled_tests) = TRUE;
+					IIUT_C_TESTENV().option.also_run_disabled_tests = TRUE;
 				}
 				else if( iu_strstr(arg, "break_on_failure") == arg )
 				{
@@ -624,7 +455,7 @@ static iuBOOL	iuTestEnv_ParseCommandLineElemA(const char* arg)
 				}
 				else if( iuString_IsStringEqual(arg, "shuffle") )
 				{
-					IUTEST_FLAG(shuffle) = TRUE;
+					IIUT_C_TESTENV().option.shuffle = TRUE;
 				}
 				else if( iu_strstr(arg, "random_seed") == arg )
 				{
@@ -800,57 +631,6 @@ static void	iuTestEnv_ParseCommandLineW(int* pargc, wchar_t** argv)
 }
 #endif
 
-static void iuTestEnv_LoadEnviromentVariable(void)
-{
-	{
-		int var = 0;
-		if( iuTestOS_GetEnvironmentInt("IUTEST_ALSO_RUN_DISABLED_TESTS", &var) )
-		{
-			IUTEST_FLAG(also_run_disabled_tests) = var ? TRUE : FALSE;
-		}
-		if( iuTestOS_GetEnvironmentInt("IUTEST_SHUFFLE", &var) )
-		{
-			IUTEST_FLAG(shuffle) = var ? TRUE : FALSE;
-		}
-		if( iuTestOS_GetEnvironmentInt("IUTEST_BREAK_ON_FAILURE", &var) )
-		{
-			IUTEST_FLAG(break_on_failure) = var ? TRUE : FALSE;
-		}
-		if( iuTestOS_GetEnvironmentInt("IUTEST_RANDOM_SEED", &var) )
-		{
-			IUTEST_FLAG(random_seed) = (unsigned int)var;
-		}
-		if( iuTestOS_GetEnvironmentInt("IUTEST_PRINT_TIME", &var) )
-		{
-			IUTEST_FLAG(print_time) = var ? TRUE : FALSE;
-		}
-		if( iuTestOS_GetEnvironmentInt("IUTEST_REPEAT", &var) )
-		{
-			IUTEST_FLAG(repeat) = var;
-		}
-	}
-	{
-		char var[128] = {0};
-		if( iuTestOS_GetEnvironmentVariable("IUTEST_COLOR", var, 128) )
-		{
-			iuTestEnv_ParseColorOption(var);
-		}
-	}
-	{
-		char path[260+32] = {0};
-		if( iuTestOS_GetEnvironmentVariable("IUTEST_OUTPUT", path, sizeof(path)) )
-		{
-			iuTestEnv_ParseOutputOption(path);
-		}
-		if( iuTestOS_GetEnvironmentVariable("IUTEST_FILTER", path, sizeof(path)) )
-		{
-			static char f[260+32];
-			iu_strcpy(f, path);
-			IUTEST_FLAG(filter) = f;
-		}
-	}
-}
-
 /**
  * @brief	yes IvV
 */
@@ -963,32 +743,4 @@ static iuBOOL	iuTestEnv_ParseYesNoFlagOption(const char* option, iuBOOL* flag, i
 	return TRUE;
 }
 
-/**
- * @brief	iuTestGlobalEnvSetUp ̍쐬
-*/
-static iuTestGlobalEnvSetUp*	iuTestEnv_AllocGlobalEnvSetUp(void)
-{
-#if IUTEST_C_HAS_MALLOC
-	return (iuTestGlobalEnvSetUp*)iu_malloc(sizeof(iuTestGlobalEnvSetUp));
-#else
-	iuTestGlobalEnvSetUp* ptr = NULL;
-	IUTEST_C_AllocByPool(ptr, iuTestGlobalEnvSetUp, IUTEST_C_GLOBALENVSETUP_POOL_COUNT);
-	return ptr;
-#endif
-}
-
-/**
- * @brief	iuTestGlobalEnvTearDown ̍쐬
-*/
-static iuTestGlobalEnvTearDown*	iuTestEnv_AllocGlobalEnvTearDown(void)
-{
-#if IUTEST_C_HAS_MALLOC
-	return (iuTestGlobalEnvTearDown*)iu_malloc(sizeof(iuTestGlobalEnvTearDown));
-#else
-	iuTestGlobalEnvTearDown* ptr = NULL;
-	IUTEST_C_AllocByPool(ptr, iuTestGlobalEnvTearDown, IUTEST_C_GLOBALENVTEARDOWN_POOL_COUNT);
-	return ptr;
-#endif
-}
-
 #endif
